@@ -1,9 +1,9 @@
 package HTML::FormFu::Constraint::Callback;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-__PACKAGE__->mk_item_accessors(qw( callback ));
+has callback => ( is => 'rw', traits  => ['Chained'] );
 
 sub constrain_value {
     my ( $self, $value, $params ) = @_;
@@ -17,6 +17,8 @@ sub constrain_value {
     return $ok;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -68,13 +70,6 @@ Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
 
-=head1 LIMITATIONS
-
-The callback code-ref is copied internally using L<Storable/dclone>. It
-seems that because of this, the coderef does not act as a true closure, and
-cannot refer to variables and subroutines that would otherwise be in scope.
-This need further investigation.
-
 =head1 AUTHOR
 
 Carl Franks C<cfranks@cpan.org>
@@ -83,3 +78,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
