@@ -1,12 +1,20 @@
 package HTML::FormFu::Constraint::Length;
+use Moose;
+use MooseX::Aliases;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+extends 'HTML::FormFu::Constraint';
 
-__PACKAGE__->mk_item_accessors(qw( minimum maximum ));
+has minimum => (
+    is      => 'rw',
+    alias   => 'min',
+    traits  => ['Chained'],
+);
 
-*min = \&minimum;
-*max = \&maximum;
+has maximum => (
+    is      => 'rw',
+    alias   => 'max',
+    traits  => ['Chained'],
+);
 
 sub constrain_value {
     my ( $self, $value ) = @_;
@@ -30,6 +38,8 @@ sub _localize_args {
     return $self->min, $self->max;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -76,3 +86,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
